@@ -7,7 +7,7 @@ CGI::Ex::Fill - Fast but compliant regex based form filler
 =cut
 
 ###----------------------------------------------------------------###
-#  Copyright 2003-2015 - Paul Seamons                                #
+#  Copyright 2003-2017 - Paul Seamons                                #
 #  Distributed under the Perl Artistic License without warranty      #
 ###----------------------------------------------------------------###
 
@@ -24,7 +24,7 @@ use vars qw($VERSION
 use base qw(Exporter);
 
 BEGIN {
-    $VERSION   = '2.44';
+    $VERSION   = '2.45';
     @EXPORT    = qw(form_fill);
     @EXPORT_OK = qw(fill form_fill html_escape get_tagval_by_key swap_tagval_by_key);
 };
@@ -194,9 +194,7 @@ sub fill {
 
             if ($name && ! $ignore->{$name}) {
                 if (! $type
-                    || $type eq 'HIDDEN'
-                    || $type eq 'TEXT'
-                    || $type eq 'FILE'
+                    || ($type ne 'PASSWORD' && $type ne 'CHECKBOX' && $type ne 'RADIO')
                     || ($type eq 'PASSWORD' && $fill_password)) {
 
                     my $value = $get_form_value->($name, 'next');
